[Cmake-commits] CMake branch, next, updated. v3.2.0-rc2-776-gc902929

Nils Gladitz nilsgladitz at gmail.com
Fri Feb 27 10:32:54 EST 2015


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
       via  c902929e98100e5895b7d06b2c9d06e9dcce4423 (commit)
       via  6a661f06030b85b4484733375bbb0aa23eca7446 (commit)
       via  4bef659da525441464ed110d362b46a6eac50a82 (commit)
      from  0c5c6acd4b370fed01ba977ac9dee77fd0f9eba3 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=c902929e98100e5895b7d06b2c9d06e9dcce4423
commit c902929e98100e5895b7d06b2c9d06e9dcce4423
Merge: 0c5c6ac 6a661f0
Author:     Nils Gladitz <nilsgladitz at gmail.com>
AuthorDate: Fri Feb 27 10:32:53 2015 -0500
Commit:     CMake Topic Stage <kwrobot at kitware.com>
CommitDate: Fri Feb 27 10:32:53 2015 -0500

    Merge topic 'fix-ctest-update-locale' into next
    
    6a661f06 CTest: To enforce the C locale use LC_ALL instead of LC_MESSAGES.
    4bef659d CMake Nightly Date Stamp


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=6a661f06030b85b4484733375bbb0aa23eca7446
commit 6a661f06030b85b4484733375bbb0aa23eca7446
Author:     Nils Gladitz <nilsgladitz at gmail.com>
AuthorDate: Fri Feb 27 16:32:03 2015 +0100
Commit:     Nils Gladitz <nilsgladitz at gmail.com>
CommitDate: Fri Feb 27 16:32:03 2015 +0100

    CTest: To enforce the C locale use LC_ALL instead of LC_MESSAGES.
    
    If LC_ALL is set it takes precedence over LC_MESSAGES.

diff --git a/Source/CTest/cmCTestUpdateHandler.cxx b/Source/CTest/cmCTestUpdateHandler.cxx
index b18786a..b9da8a0 100644
--- a/Source/CTest/cmCTestUpdateHandler.cxx
+++ b/Source/CTest/cmCTestUpdateHandler.cxx
@@ -72,37 +72,37 @@ public:
   cmCTestUpdateHandlerLocale();
   ~cmCTestUpdateHandlerLocale();
 private:
-  std::string saveLCMessages;
+  std::string saveLCAll;
 };
 
 cmCTestUpdateHandlerLocale::cmCTestUpdateHandlerLocale()
 {
-  const char* lcmess = cmSystemTools::GetEnv("LC_MESSAGES");
-  if(lcmess)
+  const char* lcall = cmSystemTools::GetEnv("LC_ALL");
+  if(lcall)
     {
-    saveLCMessages = lcmess;
+    saveLCAll = lcall;
     }
-  // if LC_MESSAGES is not set to C, then
+  // if LC_ALL is not set to C, then
   // set it, so that svn/cvs info will be in english ascii
-  if(! (lcmess && strcmp(lcmess, "C") == 0))
+  if(! (lcall && strcmp(lcall, "C") == 0))
     {
-    cmSystemTools::PutEnv("LC_MESSAGES=C");
+    cmSystemTools::PutEnv("LC_ALL=C");
     }
 }
 
 cmCTestUpdateHandlerLocale::~cmCTestUpdateHandlerLocale()
 {
   // restore the value of LC_MESSAGES after running the version control
   // commands
-  if(!saveLCMessages.empty())
+  if(!saveLCAll.empty())
     {
-    std::string put = "LC_MESSAGES=";
-    put += saveLCMessages;
+    std::string put = "LC_ALL=";
+    put += saveLCAll;
     cmSystemTools::PutEnv(put);
     }
   else
     {
-    cmSystemTools::UnsetEnv("LC_MESSAGES");
+    cmSystemTools::UnsetEnv("LC_ALL");
     }
 }
 

-----------------------------------------------------------------------

Summary of changes:
 Source/CMakeVersion.cmake             |    2 +-
@@ -72,37 +72,37 @@ public:
 cmCTestUpdateHandlerLocale::~cmCTestUpdateHandlerLocale()
 {
-  // restore the value of LC_MESSAGES after running the version control
+  // restore the value of LC_ALL after running the version control
   // commands
 Source/CTest/cmCTestUpdateHandler.cxx |   24 ++++++++++++------------
 2 files changed, 13 insertions(+), 13 deletions(-)


hooks/post-receive
-- 
CMake


More information about the Cmake-commits mailing list